# Instance Selection Methods
This project has the following algorithms:
- ENN
  - The most pure Wilson Editing,
  - and a modified version to work with self-training in case there are some 
    instances that the author do not want them removed (safe).
- CNN
- RNN
- MSS
- ICF
- LocalSets
  - LSSm
  - LSBo


Release Notes
=============

See the commit logs at https://github.com/dpr1005/Semisupervised-learning-and-instance-selection-methods.